==> ui-1.7.2-sources.jar: nanorep/nanowidget/Components/NRCategoriesView.java <==
package nanorep.nanowidget.Components;

import android.content.Context;
import android.support.v7.widget.DividerItemDecoration;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.nanorep.nanoclient.Nanorep;
import com.nanorep.nanoclient.Response.NRFAQGroupItem;

import java.util.ArrayList;

import nanorep.nanowidget.DataClass.NRCategoriesAdapter;
import nanorep.nanowidget.DataClass.NRLabelsAdapter;
import nanorep.nanowidget.R;
import nanorep.nanowidget.interfaces.NRCustomViewAdapter;

/**
 * Created by noat on 08/11/2016.
 */

public class NRCategoriesView extends LinearLayout {

    private RecyclerView mResultsRecyclerView;
    private FrameLayout loadingview;
    private TextView faqTitle;


    public interface Listener {
        void onCategorySelected(NRFAQGroupItem groupItem);
    }

    public NRCategoriesView(Context context) {
        super(context);
        LayoutInflater.from(context).inflate(R.layout.results_view, this);
    }

    @Override
    public void onViewAdded(View child) {
        super.onViewAdded(child);
        faqTitle = (TextView) child.findViewById(R.id.faqTitle);
        mResultsRecyclerView = (RecyclerView) child.findViewById(R.id.resultsView);
        mResultsRecyclerView.setLayoutManager(new LinearLayoutManager(this.getContext()));
        mResultsRecyclerView.setItemAnimator(null);
        mResultsRecyclerView.addItemDecoration(new SimpleDividerItemDecoration(getContext(), getResources(), SimpleDividerItemDecoration.PAGE_LABELS));
        loadingview = (FrameLayout) child.findViewById(R.id.loading_layout);
        faqTitle.setVisibility(GONE);


    }

    public void setCategories(ArrayList<NRFAQGroupItem> categories, NRCustomViewAdapter viewAdapter, Listener listener)  {
        NRCategoriesAdapter adapter = new NRCategoriesAdapter();
        adapter.setListener(listener);
        adapter.setViewAdapter(viewAdapter);
        adapter.addItems(categories);
        mResultsRecyclerView.addItemDecoration(new SimpleDividerItemDecoration(getContext(), getResources(), SimpleDividerItemDecoration.PAGE_LABELS));

        mResultsRecyclerView.setAdapter(adapter);
    }

    public void setLabels(NRLabelsAdapter.NRLabelsListener listener) {
        mResultsRecyclerView.setAdapter(new NRLabelsAdapter(listener));
    }

    public void setLoading(boolean loading) {
        loadingview.setVisibility(loading ? VISIBLE : GONE);
    }
}

==> ui-1.7.5-sources.jar: nanorep/nanowidget/Components/NRCategoriesView.java <==
package nanorep.nanowidget.Components;

import android.content.Context;
import android.support.v7.widget.DividerItemDecoration;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.nanorep.nanoclient.Nanorep;
import com.nanorep.nanoclient.Response.NRFAQGroupItem;

import java.util.ArrayList;

import nanorep.nanowidget.DataClass.NRCategoriesAdapter;
import nanorep.nanowidget.DataClass.NRLabelsAdapter;
import nanorep.nanowidget.R;
import nanorep.nanowidget.interfaces.NRCustomViewAdapter;

/**
 * Created by noat on 08/11/2016.
 */

public class NRCategoriesView extends LinearLayout {

    private RecyclerView mResultsRecyclerView;
    private FrameLayout loadingview;
    private TextView faqTitle;


    public interface Listener {
        void onCategorySelected(NRFAQGroupItem groupItem);
    }

    public NRCategoriesView(Context context) {
        super(context);
        LayoutInflater.from(context).inflate(R.layout.results_view, this);
    }

    @Override
    public void onViewAdded(View child) {
        super.onViewAdded(child);
        faqTitle = child.findViewById(R.id.faqTitle);
        mResultsRecyclerView = child.findViewById(R.id.resultsView);
        mResultsRecyclerView.setLayoutManager(new LinearLayoutManager(this.getContext()));
        mResultsRecyclerView.setItemAnimator(null);
        mResultsRecyclerView.addItemDecoration(new SimpleDividerItemDecoration(getContext(), getResources(), SimpleDividerItemDecoration.PAGE_LABELS));
        loadingview = child.findViewById(R.id.loading_layout);
        faqTitle.setVisibility(GONE);


    }

    public void setCategories(ArrayList<NRFAQGroupItem> categories, NRCustomViewAdapter viewAdapter, Listener listener)  {
        NRCategoriesAdapter adapter = new NRCategoriesAdapter();
        adapter.setListener(listener);
        adapter.setViewAdapter(viewAdapter);
        adapter.addItems(categories);
        mResultsRecyclerView.addItemDecoration(new SimpleDividerItemDecoration(getContext(), getResources(), SimpleDividerItemDecoration.PAGE_LABELS));

        mResultsRecyclerView.setAdapter(adapter);
    }

    public void setLabels(NRLabelsAdapter.NRLabelsListener listener) {
        mResultsRecyclerView.setAdapter(new NRLabelsAdapter(listener));
    }

    public void setLoading(boolean loading) {
        loadingview.setVisibility(loading ? VISIBLE : GONE);
    }
}
